@@ -1,60 +1,60 @@
 from typing import List, Optional
 from ddd_objects.domain.entity import Entity, ExpiredEntity
 from .value_obj import (
-    KeyType,
-    NodeType,
-    Bool,
-    DNSLine,
-    Username,
-    Token,
-    RegionID,
-    Key,
-    InternetPayType,
-    Endpoint,
-    Time,
-    ZoneID,
-    InstanceTypeStatus,
-    Usage,
-    TimeInterval,
-    BandWidth,
     PayType,
-    Path,
     Value,
-    DateTime,
-    IngressHost,
+    Number,
+    BandWidth,
+    DNSType,
+    GPUType,
+    NodeName,
+    Subdomain,
+    ZoneID,
+    Bool,
+    Time,
+    Path,
+    Port,
+    Version,
+    Password,
+    ServiceType,
+    DNSLine,
+    SecurityGroupID,
+    NodeType,
+    KeyType,
+    DomainName,
+    RegionID,
+    RecordID,
+    Price,
+    Token,
+    NodeLabel,
+    Output,
+    Command,
+    Size,
+    InstanceID,
+    Key,
+    Endpoint,
     Name,
+    InstanceName,
+    Type,
+    InstanceTypeStatus,
+    Hostname,
+    IngressHost,
+    InternetPayType,
+    ImageID,
+    Usage,
+    NodeStatus,
     Info,
     Weight,
-    NodeStatus,
-    RecordID,
-    InstanceType,
-    NodeLabel,
-    Version,
-    NodeName,
-    InstanceName,
-    Size,
-    Data,
-    GPUType,
-    ServiceType,
-    Password,
-    IP,
-    ImageID,
-    Hostname,
-    SecurityGroupID,
-    DNSType,
-    Number,
-    Subdomain,
-    Command,
-    InstanceID,
-    Port,
-    DomainName,
-    Status,
-    PodStatus,
-    Output,
-    Type,
-    InstanceTypeStatusCategory,
     ID,
-    Price
+    PodStatus,
+    InstanceType,
+    DateTime,
+    TimeInterval,
+    InstanceTypeStatusCategory,
+    Data,
+    IP,
+    Username,
+    Status
 )
 
 class Condition(Entity):
@@ -263,16 +263,7 @@ class NodeInfo(ExpiredEntity):
         security_group_id: List[SecurityGroupID],
         node_label: NodeLabel,
         cpu_number: Number,
-        cpu_usage: Usage,
         memory_size: Size,
-        actual_memory_size: Size,
-        memory_usage: Size,
-        flow_in: Size,
-        flow_out: Size,
-        disk_size: Size,
-        disk_usage: Usage,
-        io_in: Number,
-        io_out: Number,
         gpu_type: GPUType,
         gpu_number: Number,
         instance_type_status: InstanceTypeStatus,
@@ -307,16 +298,7 @@ class NodeInfo(ExpiredEntity):
         self.security_group_id=security_group_id
         self.node_label=node_label
         self.cpu_number=cpu_number
-        self.cpu_usage=cpu_usage
         self.memory_size=memory_size
-        self.actual_memory_size=actual_memory_size
-        self.memory_usage=memory_usage
-        self.flow_in=flow_in
-        self.flow_out=flow_out
-        self.disk_size=disk_size
-        self.disk_usage=disk_usage
-        self.io_in=io_in
-        self.io_out=io_out
         self.gpu_type=gpu_type
         self.gpu_number=gpu_number
         self.instance_type_status=instance_type_status
