@@ -34,7 +34,7 @@ from ..domain.value_obj import (
 
 class K3SRepository(Repository):
 
-    def add_node_label(self, node_infos: List[Union[NodeInfo, NodeMeta]], key: Key, value: Value)->Optional[List[CommandResult]]:
+    def add_node_label(self, node_infos: List[Union[NodeInfo, NodeMeta]], key: Key, value: Value)->Optional[List[bool]]:
         raise NotImplementedError
 
     def check_connection(self, )->Optional[Bool]:
