@@ -118,7 +118,7 @@ class K3SController:
             headers=self.header, data=data, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
-        return [CommandResultDO(**r) for r in infos]
+        return infos
 
     @exception_class_dec(max_try=1)
     def get_namespaces(self, cluster_name: str, timeout=30):
