@@ -48,16 +48,7 @@ class NodeInfoDO(BaseDO):
     security_group_id: List[str]
     node_label: str
     cpu_number: int
-    cpu_usage: float
     memory_size: float
-    actual_memory_size: float
-    memory_usage: float
-    flow_in: float
-    flow_out: float
-    disk_size: float
-    disk_usage: float
-    io_in: float
-    io_out: float
     gpu_type: str
     gpu_number: int
     instance_type_status: str
