@@ -129,7 +129,7 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         node_infos: List[Union[NodeInfo, NodeMeta]], 
         key: Key, 
         value: Value
-    )->Optional[List[CommandResult]]:
+    )->Optional[List[bool]]:
         node_infos = [
             node_info_converter.to_do(x) if isinstance(x, NodeInfo) 
             else node_meta_converter.to_do(x)
@@ -138,7 +138,7 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         value = value.get_value()
         result = self.ao.add_node_label(node_infos, key, value)
         if result.succeed:
-            return [command_result_converter.to_entity(x) for x in result.get_value()]
+            return result.get_value()
         else:
             self.log_func(result.error_traceback)
             return None
